@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2016, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -35,14 +35,16 @@ import java.util.Comparator;
 import java.util.List;
 import java.util.Objects;
 
+import jdk.jfr.Configuration;
+import jdk.jfr.EventType;
 import jdk.jfr.Timespan;
 import jdk.jfr.Timestamp;
 import jdk.jfr.ValueDescriptor;
-import jdk.jfr.internal.consumer.JdkJfrConsumer;
-import jdk.jfr.internal.consumer.ObjectFactory;
 import jdk.jfr.internal.PrivateAccess;
 import jdk.jfr.internal.Type;
+import jdk.jfr.internal.consumer.JdkJfrConsumer;
 import jdk.jfr.internal.consumer.ObjectContext;
+import jdk.jfr.internal.consumer.ObjectFactory;
 import jdk.jfr.internal.tool.PrettyWriter;
 
 /**
@@ -55,14 +57,17 @@ import jdk.jfr.internal.tool.PrettyWriter;
  *
  * @since 9
  */
-public class RecordedObject {
-
+public sealed class RecordedObject
+   permits RecordedEvent, RecordedClassLoader, RecordedClass, RecordedMethod,
+           RecordedStackTrace, RecordedFrame, RecordedThread, RecordedThreadGroup {
     static{
         JdkJfrConsumer access = new JdkJfrConsumer() {
+            @Override
             public List<Type> readTypes(RecordingFile file) throws IOException {
                 return file.readTypes();
             }
 
+            @Override
             public boolean isLastEventInChunk(RecordingFile file) {
                 return file.isLastEventInChunk();
             }
@@ -136,20 +141,17 @@ public class RecordedObject {
             public Object[] eventValues(RecordedEvent event) {
                 return event.objects;
             }
+
+            @Override
+            public MetadataEvent newMetadataEvent(List<EventType> previous, List<EventType> current,
+                    List<Configuration> configurations) {
+                return new MetadataEvent(previous, current, configurations);
+            }
         };
         JdkJfrConsumer.setAccess(access);
     }
 
-    private final static class UnsignedValue {
-        private final Object o;
-
-        UnsignedValue(Object o) {
-            this.o = o;
-        }
-
-        Object value() {
-            return o;
-        }
+    private static final record UnsignedValue(Object value) {
     }
 
     final Object[] objects;
@@ -179,10 +181,13 @@ public class RecordedObject {
     /**
      * Returns {@code true} if a field with the given name exists, {@code false}
      * otherwise.
+     * <p>
+     * It's possible to index into a nested field by using {@code "."} (for
+     * instance {@code "thread.group.parent.name}").
      *
      * @param name name of the field to get, not {@code null}
      *
-     * @return {@code true} if the field exists, {@code false} otherwise.
+     * @return {@code true} if the field exists, {@code false} otherwise
      *
      * @see #getFields()
      */
@@ -221,25 +226,7 @@ public class RecordedObject {
      * for callers of this method is to validate the field before attempting access.
      * <p>
      * Example
-     *
-     * <pre>
-     * <code>
-     * if (event.hasField("intValue")) {
-     *   int intValue = event.getValue("intValue");
-     *   System.out.println("Int value: " + intValue);
-     * }
-     *
-     * if (event.hasField("objectClass")) {
-     *   RecordedClass clazz = event.getValue("objectClass");
-     *   System.out.println("Class name: " + clazz.getName());
-     * }
-     *
-     * if (event.hasField("sampledThread")) {
-     *   RecordedThread sampledThread = event.getValue("sampledThread");
-     *   System.out.println("Sampled thread: " + sampledThread.getName());
-     * }
-     * </code>
-     * </pre>
+     * {@snippet class="Snippets" region="RecordedObjectGetValue"}
      *
      * @param <T> the return type
      * @param  name of the field to get, not {@code null}
@@ -250,18 +237,18 @@ public class RecordedObject {
      * @see #hasField(String)
      *
      */
-    final public <T> T getValue(String name) {
+    public final <T> T getValue(String name) {
         @SuppressWarnings("unchecked")
         T t = (T) getValue(name, false);
         return t;
     }
 
-    protected Object objectAt(int index) {
+    Object objectAt(int index) {
         return objects[index];
     }
 
     private Object getValue(String name, boolean allowUnsigned) {
-        Objects.requireNonNull(name);
+        Objects.requireNonNull(name, "name");
         int index = 0;
         for (ValueDescriptor v : objectContext.fields) {
             if (name.equals(v.getName())) {
@@ -343,14 +330,14 @@ public class RecordedObject {
                 return v;
             }
         }
-        throw new IllegalArgumentException("\"Attempt to get unknown field \"" + name + "\"");
+        throw new IllegalArgumentException("Attempt to get unknown field \"" + name + "\"");
     }
 
     // Gets a value, but checks that type and name is correct first
     // This is to prevent a call to getString on a thread field, that is
     // null to succeed.
     private <T> T getTypedValue(String name, String typeName) {
-        Objects.requireNonNull(name);
+        Objects.requireNonNull(name, "name");
         // Validate name and type first
         getValueDescriptor(objectContext.fields, name, typeName);
         return getValue(name);
@@ -419,8 +406,8 @@ public class RecordedObject {
      */
     public final boolean getBoolean(String name) {
         Object o = getValue(name);
-        if (o instanceof Boolean) {
-            return ((Boolean) o).booleanValue();
+        if (o instanceof Boolean b) {
+            return b;
         }
         throw newIllegalArgumentException(name, "boolean");
     }
@@ -446,8 +433,8 @@ public class RecordedObject {
      */
     public final byte getByte(String name) {
         Object o = getValue(name);
-        if (o instanceof Byte) {
-            return ((Byte) o).byteValue();
+        if (o instanceof Byte b) {
+            return b;
         }
         throw newIllegalArgumentException(name, "byte");
     }
@@ -473,8 +460,8 @@ public class RecordedObject {
      */
     public final char getChar(String name) {
         Object o = getValue(name);
-        if (o instanceof Character) {
-            return ((Character) o).charValue();
+        if (o instanceof Character c) {
+            return c;
         }
 
         throw newIllegalArgumentException(name, "char");
@@ -504,23 +491,23 @@ public class RecordedObject {
      *         conversion
      *
      * @see #hasField(String)
-     * @set #getValue(String)
+     * @see #getValue(String)
      */
     public final short getShort(String name) {
         Object o = getValue(name, true);
-        if (o instanceof Short) {
-            return ((Short) o).shortValue();
+        if (o instanceof Short s) {
+            return s;
         }
-        if (o instanceof Byte) {
-            return ((Byte) o).byteValue();
+        if (o instanceof Byte b) {
+            return b;
         }
-        if (o instanceof UnsignedValue) {
-            Object u = ((UnsignedValue) o).value();
-            if (u instanceof Short) {
-                return ((Short) u).shortValue();
+        if (o instanceof UnsignedValue unsigned) {
+            Object u = unsigned.value();
+            if (u instanceof Short s) {
+                return s;
             }
-            if (u instanceof Byte) {
-                return (short) Byte.toUnsignedInt(((Byte) u));
+            if (u instanceof Byte b) {
+                return (short) Byte.toUnsignedInt(b);
             }
         }
         throw newIllegalArgumentException(name, "short");
@@ -551,32 +538,32 @@ public class RecordedObject {
      *         conversion
      *
      * @see #hasField(String)
-     * @set #getValue(String)
+     * @see #getValue(String)
      */
     public final int getInt(String name) {
         Object o = getValue(name, true);
-        if (o instanceof Integer) {
-            return ((Integer) o).intValue();
+        if (o instanceof Integer i) {
+            return i;
         }
-        if (o instanceof Short) {
-            return ((Short) o).intValue();
+        if (o instanceof Short s) {
+            return s;
         }
-        if (o instanceof Character) {
-            return ((Character) o).charValue();
+        if (o instanceof Character c) {
+            return c;
         }
-        if (o instanceof Byte) {
-            return ((Byte) o).intValue();
+        if (o instanceof Byte b) {
+            return b;
         }
-        if (o instanceof UnsignedValue) {
-            Object u = ((UnsignedValue) o).value();
-            if (u instanceof Integer) {
-                return ((Integer) u).intValue();
+        if (o instanceof UnsignedValue unsigned) {
+            Object u = unsigned.value();
+            if (u instanceof Integer i) {
+                return i;
             }
-            if (u instanceof Short) {
-                return Short.toUnsignedInt(((Short) u));
+            if (u instanceof Short s) {
+                return Short.toUnsignedInt(s);
             }
-            if (u instanceof Byte) {
-                return Byte.toUnsignedInt(((Byte) u));
+            if (u instanceof Byte b) {
+                return Byte.toUnsignedInt(b);
             }
         }
         throw newIllegalArgumentException(name, "int");
@@ -604,27 +591,27 @@ public class RecordedObject {
      *         conversion
      *
      * @see #hasField(String)
-     * @set #getValue(String)
+     * @see #getValue(String)
      */
     public final float getFloat(String name) {
         Object o = getValue(name);
-        if (o instanceof Float) {
-            return ((Float) o).floatValue();
+        if (o instanceof Float f) {
+            return f;
         }
-        if (o instanceof Long) {
-            return ((Long) o).floatValue();
+        if (o instanceof Long l) {
+            return l;
         }
-        if (o instanceof Integer) {
-            return ((Integer) o).floatValue();
+        if (o instanceof Integer i) {
+            return i;
         }
-        if (o instanceof Short) {
-            return ((Short) o).floatValue();
+        if (o instanceof Short s) {
+            return s;
         }
-        if (o instanceof Byte) {
-            return ((Byte) o).byteValue();
+        if (o instanceof Byte b) {
+            return b;
         }
-        if (o instanceof Character) {
-            return ((Character) o).charValue();
+        if (o instanceof Character c) {
+            return c;
         }
         throw newIllegalArgumentException(name, "float");
     }
@@ -654,35 +641,35 @@ public class RecordedObject {
      *         conversion
      *
      * @see #hasField(String)
-     * @set #getValue(String)
+     * @see #getValue(String)
      */
     public final long getLong(String name) {
         Object o = getValue(name, true);
-        if (o instanceof Long) {
-            return ((Long) o).longValue();
+        if (o instanceof Long l) {
+            return l;
         }
-        if (o instanceof Integer) {
-            return ((Integer) o).longValue();
+        if (o instanceof Integer i) {
+            return i;
         }
-        if (o instanceof Short) {
-            return ((Short) o).longValue();
+        if (o instanceof Short s) {
+            return s;
         }
-        if (o instanceof Character) {
-            return ((Character) o).charValue();
+        if (o instanceof Character c) {
+            return c;
         }
-        if (o instanceof Byte) {
-            return ((Byte) o).longValue();
+        if (o instanceof Byte b) {
+            return b.longValue();
         }
-        if (o instanceof UnsignedValue) {
-            Object u = ((UnsignedValue) o).value();
-            if (u instanceof Integer) {
-                return Integer.toUnsignedLong(((Integer) u));
+        if (o instanceof UnsignedValue unsigned) {
+            Object u = unsigned.value();
+            if (u instanceof Integer i) {
+                return Integer.toUnsignedLong(i);
             }
-            if (u instanceof Short) {
-                return Short.toUnsignedLong(((Short) u));
+            if (u instanceof Short s) {
+                return Short.toUnsignedLong(s);
             }
-            if (u instanceof Byte) {
-                return Byte.toUnsignedLong(((Byte) u));
+            if (u instanceof Byte b) {
+                return Byte.toUnsignedLong(b);
             }
         }
         throw newIllegalArgumentException(name, "long");
@@ -710,30 +697,30 @@ public class RecordedObject {
      *         conversion
      *
      * @see #hasField(String)
-     * @set #getValue(String)
+     * @see #getValue(String)
      */
     public final double getDouble(String name) {
         Object o = getValue(name);
-        if (o instanceof Double) {
-            return ((Double) o).doubleValue();
+        if (o instanceof Double d) {
+            return d.doubleValue();
         }
-        if (o instanceof Float) {
-            return ((Float) o).doubleValue();
+        if (o instanceof Float f) {
+            return f.doubleValue();
         }
-        if (o instanceof Long) {
-            return ((Long) o).doubleValue();
+        if (o instanceof Long l) {
+            return l.doubleValue();
         }
-        if (o instanceof Integer) {
-            return ((Integer) o).doubleValue();
+        if (o instanceof Integer i) {
+            return i.doubleValue();
         }
-        if (o instanceof Short) {
-            return ((Short) o).doubleValue();
+        if (o instanceof Short s) {
+            return s.doubleValue();
         }
-        if (o instanceof Byte) {
-            return ((Byte) o).byteValue();
+        if (o instanceof Byte b) {
+            return b.doubleValue();
         }
-        if (o instanceof Character) {
-            return ((Character) o).charValue();
+        if (o instanceof Character c) {
+            return c;
         }
         throw newIllegalArgumentException(name, "double");
     }
@@ -755,7 +742,7 @@ public class RecordedObject {
      *         isn't of type {@code String}
      *
      * @see #hasField(String)
-     * @set #getValue(String)
+     * @see #getValue(String)
      */
     public final String getString(String name) {
         return getTypedValue(name, "java.lang.String");
@@ -782,42 +769,45 @@ public class RecordedObject {
      *         value can't be converted to a {@code Duration} object
      *
      * @see #hasField(String)
-     * @set #getValue(String)
+     * @see #getValue(String)
      */
     public final Duration getDuration(String name) {
         Object o = getValue(name);
-        if (o instanceof Long) {
-            return getDuration(((Long) o).longValue(), name);
+        if (o instanceof Long l) {
+            return getDuration(l, name);
         }
-        if (o instanceof Integer) {
-            return getDuration(((Integer) o).longValue(), name);
+        if (o instanceof Integer i) {
+            return getDuration(i, name);
         }
-        if (o instanceof Short) {
-            return getDuration(((Short) o).longValue(), name);
+        if (o instanceof Short s) {
+            return getDuration(s, name);
         }
-        if (o instanceof Character) {
-            return getDuration(((Character) o).charValue(), name);
+        if (o instanceof Character c) {
+            return getDuration(c, name);
         }
-        if (o instanceof Byte) {
-            return getDuration(((Byte) o).longValue(), name);
+        if (o instanceof Byte b) {
+            return getDuration(b, name);
         }
-        if (o instanceof UnsignedValue) {
-            Object u = ((UnsignedValue) o).value();
-            if (u instanceof Integer) {
-                return getDuration(Integer.toUnsignedLong((Integer) u), name);
+        if (o instanceof UnsignedValue unsigned) {
+            Object u = unsigned.value();
+            if (u instanceof Integer i) {
+                return getDuration(Integer.toUnsignedLong(i), name);
             }
-            if (u instanceof Short) {
-                return getDuration(Short.toUnsignedLong((Short) u), name);
+            if (u instanceof Short s) {
+                return getDuration(Short.toUnsignedLong(s), name);
             }
-            if (u instanceof Byte) {
-                return getDuration(Short.toUnsignedLong((Byte) u), name);
+            if (u instanceof Byte b) {
+                return getDuration(Short.toUnsignedLong(b), name);
             }
         }
-        throw newIllegalArgumentException(name, "java,time.Duration");
+        throw newIllegalArgumentException(name, "java.time.Duration");
     }
 
-    private Duration getDuration(long timespan, String name) throws InternalError {
+    private Duration getDuration(long timespan, String name) {
         ValueDescriptor v = getValueDescriptor(objectContext.fields, name, null);
+        if (timespan == 0) {
+            return Duration.ZERO;
+        }
         if (timespan == Long.MIN_VALUE) {
             return Duration.ofSeconds(Long.MIN_VALUE, 0);
         }
@@ -861,35 +851,35 @@ public class RecordedObject {
      *         value can't be converted to an {@code Instant} object
      *
      * @see #hasField(String)
-     * @set #getValue(String)
+     * @see #getValue(String)
      */
     public final Instant getInstant(String name) {
         Object o = getValue(name, true);
-        if (o instanceof Long) {
-            return getInstant(((Long) o).longValue(), name);
+        if (o instanceof Long l) {
+            return getInstant(l, name);
         }
-        if (o instanceof Integer) {
-            return getInstant(((Integer) o).longValue(), name);
+        if (o instanceof Integer i) {
+            return getInstant(i, name);
         }
-        if (o instanceof Short) {
-            return getInstant(((Short) o).longValue(), name);
+        if (o instanceof Short s) {
+            return getInstant(s, name);
         }
-        if (o instanceof Character) {
-            return getInstant(((Character) o).charValue(), name);
+        if (o instanceof Character c) {
+            return getInstant(c, name);
         }
-        if (o instanceof Byte) {
-            return getInstant(((Byte) o).longValue(), name);
+        if (o instanceof Byte b) {
+            return getInstant(b, name);
         }
-        if (o instanceof UnsignedValue) {
-            Object u = ((UnsignedValue) o).value();
-            if (u instanceof Integer) {
-                return getInstant(Integer.toUnsignedLong((Integer) u), name);
+        if (o instanceof UnsignedValue unsigned) {
+            Object u = unsigned.value();
+            if (u instanceof Integer i) {
+                return getInstant(Integer.toUnsignedLong(i), name);
             }
-            if (u instanceof Short) {
-                return getInstant(Short.toUnsignedLong((Short) u), name);
+            if (u instanceof Short s) {
+                return getInstant(Short.toUnsignedLong(s), name);
             }
-            if (u instanceof Byte) {
-                return getInstant(Short.toUnsignedLong((Byte) u), name);
+            if (u instanceof Byte b) {
+                return getInstant(Short.toUnsignedLong(b), name);
             }
         }
         throw newIllegalArgumentException(name, "java.time.Instant");
@@ -931,7 +921,7 @@ public class RecordedObject {
      *         isn't of type {@code Class}
      *
      * @see #hasField(String)
-     * @set #getValue(String)
+     * @see #getValue(String)
      */
     public final RecordedClass getClass(String name) {
         return getTypedValue(name, "java.lang.Class");
@@ -955,7 +945,7 @@ public class RecordedObject {
      *         isn't of type {@code Thread}
      *
      * @see #hasField(String)
-     * @set #getValue(String)
+     * @see #getValue(String)
      */
     public final RecordedThread getThread(String name) {
         return getTypedValue(name, "java.lang.Thread");
@@ -967,12 +957,12 @@ public class RecordedObject {
      * @return textual description of this object
      */
     @Override
-    final public String toString() {
+    public final String toString() {
         StringWriter s = new StringWriter();
         PrettyWriter p = new PrettyWriter(new PrintWriter(s));
         p.setStackDepth(5);
-        if (this instanceof RecordedEvent) {
-            p.print((RecordedEvent) this);
+        if (this instanceof RecordedEvent event) {
+            p.print(event);
         } else {
             p.print(this, "");
         }
@@ -986,7 +976,7 @@ public class RecordedObject {
         if (instant.equals(Instant.MIN)) {
             return OffsetDateTime.MIN;
         }
-        return OffsetDateTime.ofInstant(getInstant(name), objectContext.getZoneOffset());
+        return OffsetDateTime.ofInstant(instant, objectContext.getZoneOffset());
     }
 
     private static IllegalArgumentException newIllegalArgumentException(String name, String typeName) {
