@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -153,7 +153,7 @@ public class LocaleNames_ca extends OpenListResourceBundle {
             { "AU", "Austr\u00e0lia" },
             { "AW", "Aruba" },
             { "en_US", "angl\u00e8s americ\u00e0" },
-            { "AX", "Illes \u00c5land" },
+            { "AX", "Illes Aland" },
             { "mye", "myene" },
             { "AZ", "Azerbaidjan" },
             { "%%AREVELA", "armeni oriental" },
@@ -169,13 +169,13 @@ public class LocaleNames_ca extends OpenListResourceBundle {
             { "BH", "Bahrain" },
             { "BI", "Burundi" },
             { "BJ", "Ben\u00edn" },
-            { "BL", "Saint Barth\u00e9lemy" },
+            { "BL", "Saint-Barth\u00e9lemy" },
             { "BM", "Bermudes" },
             { "kut", "kutenai" },
             { "myv", "mordovi\u00e0 erza" },
             { "BN", "Brunei" },
             { "BO", "Bol\u00edvia" },
-            { "BQ", "Carib Neerland\u00e8s" },
+            { "BQ", "Antilles Neerlandeses" },
             { "BR", "Brasil" },
             { "BS", "Bahames" },
             { "xog", "soga" },
@@ -281,7 +281,6 @@ public class LocaleNames_ca extends OpenListResourceBundle {
             { "pcd", "picard" },
             { "tkl", "tokelau\u00e8s" },
             { "grb", "grebo" },
-            { "root", "arrel" },
             { "type.ca.indian", "calendari hind\u00fa" },
             { "rgn", "romany\u00e8s" },
             { "grc", "grec antic" },
@@ -310,6 +309,7 @@ public class LocaleNames_ca extends OpenListResourceBundle {
             { "GU", "Guam" },
             { "pdc", "alemany pennsilvani\u00e0" },
             { "GW", "Guinea Bissau" },
+            { "rhg", "rohingya" },
             { "tli", "tlingit" },
             { "tlh", "klingoni\u00e0" },
             { "Talu", "nou tai lue" },
@@ -382,7 +382,7 @@ public class LocaleNames_ca extends OpenListResourceBundle {
             { "KI", "Kiribati" },
             { "KM", "Comores" },
             { "Knda", metaValue_kn },
-            { "KN", "Saint Christopher i Nevis" },
+            { "KN", "Saint Kitts i Nevis" },
             { "Zinh", "heretat" },
             { "fr_CA", "franc\u00e8s canadenc" },
             { "KP", "Corea del Nord" },
@@ -559,7 +559,7 @@ public class LocaleNames_ca extends OpenListResourceBundle {
             { "Loma", "loma" },
             { "015", "\u00c0frica septentrional" },
             { "SG", "Singapur" },
-            { "SH", "Saint Helena" },
+            { "SH", "Santa Helena" },
             { "type.lb.strict", "salt de l\u00ednia estricte" },
             { "017", "\u00c0frica central" },
             { "SI", "Eslov\u00e8nia" },
@@ -651,8 +651,8 @@ public class LocaleNames_ca extends OpenListResourceBundle {
             { "pro", "proven\u00e7al antic" },
             { "VC", "Saint Vincent i les Grenadines" },
             { "VE", "Vene\u00e7uela" },
-            { "VG", "Illes Verges Brit\u00e0niques" },
-            { "VI", "Illes Verges Nord-americanes" },
+            { "VG", "Illes Verges brit\u00e0niques" },
+            { "VI", "Illes Verges nord-americanes" },
             { "VN", "Vietnam" },
             { "VU", "Vanuatu" },
             { "nog", "nogai" },
