@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -66,74 +66,78 @@ import sun.util.resources.OpenListResourceBundle;
 public class LocaleNames_es_419 extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
+        final String metaValue_gu = "gujarati";
+        final String metaValue_ml = "malabar";
         final Object[][] data = new Object[][] {
+            { "Olck", "ol chiki" },
+            { "goh", "alem\u00e1n de la alta edad antigua" },
+            { "ace", "achen\u00e9s" },
+            { "lo", "laosiano" },
+            { "ht", "haitiano" },
+            { "030", "Asia del Este" },
+            { "151", "Europa del Este" },
+            { "type.nu.wara", "d\u00edgitos en Warang Citi" },
+            { "154", "Europa del Norte" },
+            { "tyv", "tuvano" },
+            { "sw_CD", "swahili (Congo)" },
+            { "034", "Asia del Sur" },
+            { "155", "Europa del Oeste" },
+            { "Laoo", "lao" },
+            { "035", "Asia sudoriental" },
+            { "zun", "zuni" },
+            { "039", "Europa del Sur" },
+            { "type.nu.traditional", "n\u00fameros traducionales" },
+            { "UM", "Islas Ultramarinas de EE.UU." },
+            { "IC", "Islas Canarias" },
+            { "QO", "Islas Ultramarinas" },
+            { "ml", metaValue_ml },
+            { "AC", "Isla Ascensi\u00f3n" },
+            { "tet", "tetun" },
+            { "xal", "calmuco" },
+            { "prg", "prusiano antiguo" },
+            { "type.co.eor", "reglas de orden europeas" },
+            { "alt", "alt\u00e1i del sur" },
+            { "eu", "vasco" },
+            { "Hrkt", "katakana o hiragana" },
+            { "EZ", "Eurozona" },
+            { "Mlym", metaValue_ml },
+            { "AX", "Islas \u00c5land" },
+            { "ady", "adigeo" },
+            { "rm", "retorrom\u00e1nico" },
+            { "type.co.phonebook", "orden de agenda telef\u00f3nica" },
+            { "BA", "Bosnia-Herzegovina" },
+            { "shu", "\u00e1rabe (Chad)" },
+            { "nr", "ndebele del sur" },
+            { "sma", "sami del sur" },
+            { "nso", "sesotho del norte" },
+            { "syr", "sir\u00edaco" },
+            { "type.ca.islamic-rgsa", "calendario isl\u00e1mico (Arabia Saudita)" },
             { "011", "\u00c1frica del Oeste" },
             { "014", "\u00c1frica del Este" },
             { "015", "\u00c1frica del Norte" },
-            { "018", "\u00c1frica del Sur" },
-            { "030", "Asia del Este" },
-            { "034", "Asia del Sur" },
-            { "035", "Asia sudoriental" },
-            { "039", "Europa del Sur" },
-            { "145", "Asia del Oeste" },
-            { "151", "Europa del Este" },
-            { "154", "Europa del Norte" },
-            { "155", "Europa del Oeste" },
-            { "AC", "Isla Ascensi\u00f3n" },
-            { "AX", "Islas \u00c5land" },
-            { "BA", "Bosnia-Herzegovina" },
-            { "CG", "Rep\u00fablica del Congo" },
-            { "CI", "Costa de Marfil" },
-            { "EZ", "Eurozona" },
-            { "IC", "Islas Canarias" },
-            { "QO", "Islas Ultramarinas" },
-            { "TA", "Trist\u00e1n da Cunha" },
-            { "UM", "Islas Ultramarinas de EE.UU." },
-            { "eu", "vasco" },
-            { "gu", "gujarati" },
-            { "ht", "haitiano" },
-            { "lo", "laosiano" },
-            { "nr", "ndebele del sur" },
-            { "pa", "panyab\u00ed" },
-            { "rm", "retorrom\u00e1nico" },
-            { "st", "sesotho del sur" },
-            { "sw", "swahili" },
-            { "ace", "achen\u00e9s" },
-            { "ady", "adigeo" },
-            { "alt", "alt\u00e1i del sur" },
-            { "arp", "arapaj\u00f3" },
-            { "ars", "\u00e1rabe de N\u00e9yed" },
             { "bla", "siksik\u00e1" },
-            { "goh", "alem\u00e1n de la alta edad antigua" },
-            { "grc", "griego cl\u00e1sico" },
-            { "kbd", "cabardiano" },
-            { "krc", "karach\u00e1i-b\u00e1lkaro" },
-            { "nso", "sesotho del norte" },
-            { "prg", "prusiano antiguo" },
-            { "shu", "\u00e1rabe (Chad)" },
-            { "sma", "sami del sur" },
-            { "syr", "sir\u00edaco" },
-            { "tet", "tetun" },
-            { "tyv", "tuvano" },
-            { "wal", "walamo" },
             { "wuu", "wu" },
-            { "xal", "calmuco" },
-            { "zun", "zuni" },
-            { "Hanb", "han con bopomofo" },
-            { "Hrkt", "katakana o hiragana" },
-            { "Laoo", "lao" },
-            { "Latn", "lat\u00edn" },
-            { "Mlym", "malayalam" },
-            { "Olck", "ol chiki" },
-            { "sw_CD", "swahili (Congo)" },
-            { "type.co.eor", "reglas de orden europeas" },
-            { "type.nu.tirh", "d\u00edgitos en tirh" },
-            { "type.nu.wara", "d\u00edgitos en Warang Citi" },
+            { "018", "\u00c1frica del Sur" },
+            { "grc", "griego cl\u00e1sico" },
             { "type.co.compat", "orden anterior, para compatibilidad" },
-            { "type.co.phonebook", "orden de agenda telef\u00f3nica" },
-            { "type.nu.traditional", "n\u00fameros traducionales" },
-            { "type.ca.islamic-rgsa", "calendario isl\u00e1mico (Arabia Saudita)" },
+            { "krc", "karach\u00e1i-b\u00e1lkaro" },
+            { "arp", "arapaj\u00f3" },
+            { "st", "sesotho del sur" },
+            { "ars", "\u00e1rabe de N\u00e9yed" },
+            { "wal", "walamo" },
+            { "CG", "Rep\u00fablica del Congo" },
+            { "sw", "swahili" },
+            { "CI", "Costa de Marfil" },
+            { "ks", "cachemiro" },
+            { "Latn", "lat\u00edn" },
+            { "kbd", "cabardiano" },
+            { "TA", "Trist\u00e1n da Cunha" },
+            { "gu", metaValue_gu },
             { "type.ca.islamic-tbla", "calendario isl\u00e1mico tabular" },
+            { "pa", "panyab\u00ed" },
+            { "145", "Asia del Oeste" },
+            { "Gujr", metaValue_gu },
+            { "type.nu.tirh", "d\u00edgitos en tirh" },
         };
         return data;
     }
