@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -251,7 +247,6 @@ public class LocaleNames_gu extends OpenListResourceBundle {
             { "FR", "\u0aab\u0acd\u0ab0\u0abe\u0a82\u0ab8" },
             { "tkl", "\u0aa4\u0acb\u0a95\u0ac7\u0ab2\u0abe\u0a89" },
             { "grb", "\u0a97\u0acd\u0ab0\u0ac7\u0aac\u0acb" },
-            { "root", "\u0ab0\u0ac2\u0a9f" },
             { "type.ca.indian", "\u0aad\u0abe\u0ab0\u0aa4\u0ac0\u0aaf \u0ab0\u0abe\u0ab7\u0acd\u0a9f\u0acd\u0ab0\u0ac0\u0aaf \u0a95\u0ac7\u0ab2\u0ac7\u0aa8\u0acd\u0aa1\u0ab0" },
             { "grc", "\u0aaa\u0acd\u0ab0\u0abe\u0a9a\u0ac0\u0aa8 \u0a97\u0acd\u0ab0\u0ac0\u0a95" },
             { "GA", "\u0a97\u0ac7\u0aac\u0aa8" },
@@ -277,6 +272,7 @@ public class LocaleNames_gu extends OpenListResourceBundle {
             { "GT", "\u0a97\u0acd\u0ab5\u0abe\u0a9f\u0ac7\u0aae\u0abe\u0ab2\u0abe" },
             { "GU", "\u0a97\u0acd\u0ab5\u0abe\u0aae" },
             { "GW", "\u0a97\u0abf\u0aa8\u0ac0-\u0aac\u0abf\u0ab8\u0abe\u0a89" },
+            { "rhg", "\u0ab0\u0acb\u0ab9\u0abf\u0a82\u0a97\u0acd\u0aaf\u0abe" },
             { "tli", "\u0a95\u0acd\u0ab2\u0ac0\u0aa8\u0acd\u0a97\u0a95\u0abf\u0a9f" },
             { "tlh", "\u0a95\u0acd\u0ab2\u0abf\u0aa8\u0acd\u0a97\u0acb\u0aa8" },
             { "Talu", "\u0aa8\u0ab5\u0ac0\u0aa8 \u0aa4\u0abe\u0a87 \u0ab2\u0ac2" },
@@ -393,7 +389,7 @@ public class LocaleNames_gu extends OpenListResourceBundle {
             { "MR", "\u0aae\u0acc\u0ab0\u0abf\u0a9f\u0abe\u0aa8\u0abf\u0aaf\u0abe" },
             { "MS", "\u0aae\u0acb\u0a82\u0a9f\u0ab8\u0ac7\u0ab0\u0abe\u0aa4" },
             { "MT", "\u0aae\u0abe\u0ab2\u0acd\u0a9f\u0abe" },
-            { "type.m0.ungegn", "UNGEGN" },
+            { "type.m0.ungegn", "UN GEGN" },
             { "MU", "\u0aae\u0acb\u0ab0\u0abf\u0ab6\u0abf\u0aaf\u0ab8" },
             { "alt", "\u0aa6\u0a95\u0acd\u0ab7\u0abf\u0aa3 \u0a85\u0ab2\u0acd\u0aa4\u0abe\u0a87" },
             { "MV", "\u0aae\u0abe\u0ab2\u0aa6\u0abf\u0ab5\u0acd\u0ab8" },
@@ -783,7 +779,7 @@ public class LocaleNames_gu extends OpenListResourceBundle {
             { "bgn", "\u0aaa\u0ab6\u0acd\u0a9a\u0abf\u0aae\u0ac0 \u0aac\u0abe\u0ab2\u0acb\u0a9a\u0ac0" },
             { "yue", "\u0a95\u0ac7\u0a82\u0a9f\u0acb\u0aa8\u0ac0\u0a9d" },
             { "fo", "\u0aab\u0acb\u0ab0\u0abf\u0ab8\u0acd\u0aa4" },
-            { "type.m0.bgn", "BGN" },
+            { "type.m0.bgn", "US BGN" },
             { "umb", "\u0a89\u0aae\u0acd\u0aac\u0ac1\u0aa8\u0acd\u0aa1\u0ac2" },
             { "fr", "\u0aab\u0acd\u0ab0\u0ac7\u0aa8\u0acd\u0a9a" },
             { "sid", "\u0ab8\u0abf\u0aa6\u0abe\u0aae\u0acb" },
