@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -70,6 +66,7 @@ import sun.util.resources.OpenListResourceBundle;
 public class LocaleNames_jv extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
+        final String metaValue_002 = "Afrika";
         final String metaValue_AZ = "Azerbaijan";
         final String metaValue_DE = "J\u00e9rman";
         final String metaValue_FR = "Prancis";
@@ -86,7 +83,6 @@ public class LocaleNames_jv extends OpenListResourceBundle {
         final String metaValue_TO = "Tonga";
         final String metaValue_TR = "Turki";
         final String metaValue_WS = "Samoa";
-        final String metaValue_ar = "Arab";
         final String metaValue_el = "Yunani";
         final String metaValue_he = "Ibrani";
         final String metaValue_hy = "Armenia";
@@ -100,6 +96,8 @@ public class LocaleNames_jv extends OpenListResourceBundle {
         final String metaValue_or = "Odia";
         final String metaValue_si = "Sinhala";
         final String metaValue_ta = "Tamil";
+        final String metaValue_te = "Telugu";
+        final String metaValue_th = "Thailand";
         final Object[][] data = new Object[][] {
             { "sbp", "Sangu" },
             { "ksh", "Colonia" },
@@ -108,8 +106,8 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "Zsym", "Simbol" },
             { "fil", "Tagalog" },
             { "hmn", "Hmong" },
-            { "ban", "ban" },
             { "Zsye", "Emoji" },
+            { "ccp", "Chakma" },
             { "luy", "Luyia" },
             { "bas", "Basaa" },
             { "es_ES", "Spanyol (Eropah)" },
@@ -118,8 +116,8 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "AD", "Andora" },
             { "AE", "Uni \u00c9mirat Arab" },
             { "nl_BE", "Flemis" },
+            { "af", metaValue_002 },
             { "AF", "Afganistan" },
-            { "af", "af" },
             { "AG", "Antigua lan Barbuda" },
             { "type.ca.ethiopic", "Tanggalan Etiopia" },
             { "AI", "Anguilla" },
@@ -127,18 +125,19 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "AL", "Albani" },
             { "AM", "Arm\u00e9nia" },
             { "am", "Amharik" },
-            { "Arab", metaValue_ar },
+            { "Arab", "hija\u2019iyah" },
             { "AO", "Angola" },
             { "Jpan", metaValue_JP },
             { "AQ", "Antartika" },
-            { "ar", metaValue_ar },
             { "AR", "Arg\u00e8ntina" },
+            { "ar", "Arab" },
             { "Hrkt", "Silabaris Jepang" },
             { "AS", "Samoa Amerika" },
             { "as", "Assam" },
             { "AT", "Ostenrik" },
             { "AU", "Ostrali" },
             { "AW", "Aruba" },
+            { "en_US", "Inggris Am\u00e9rika Sar\u00e9kat" },
             { "AX", "Kapuloan Alan" },
             { "az", metaValue_AZ },
             { "AZ", metaValue_AZ },
@@ -147,13 +146,14 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "ceb", "Cebuano" },
             { "BD", "Banggalad\u00e9sa" },
             { "BE", "B\u00e8lgi" },
-            { "be", "be" },
+            { "be", "Belarus" },
             { "BF", "Burkina Faso" },
             { "BG", "Bulgari" },
             { "bg", "Bulgaria" },
             { "BH", "Bahrain" },
             { "BI", "Burundi" },
             { "BJ", "B\u00e9nin" },
+            { "BL", "Saint Barth\u00e9l\u00e9mi" },
             { "BM", "Bermuda" },
             { "bm", "Bambara" },
             { "BN", "Brun\u00e9i" },
@@ -164,7 +164,7 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "BR", "Brasil" },
             { "br", "Breton" },
             { "BS", "Bahamas" },
-            { "bs", "bs" },
+            { "bs", "Bosnia lan Hercegovina" },
             { "xog", "Soga" },
             { "BT", "Bhutan" },
             { "BV", "Pulo Bov\u00e8t" },
@@ -207,6 +207,7 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "CZ", "C\u00e9ko" },
             { "type.nu.ethi", "Angka Etiopia" },
             { "da", "Dansk" },
+            { "pt_PT", "Portugis Portugal" },
             { "de", metaValue_DE },
             { "DE", metaValue_DE },
             { "cgg", "Chiga" },
@@ -262,6 +263,7 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "fi", "Suomi" },
             { "FJ", "Fiji" },
             { "FK", "Kapuloan Falkland" },
+            { "FM", "F\u00e9derasi Mikron\u00e9sia" },
             { "yue", "Kanton" },
             { "FO", "Kapuloan Faro" },
             { "fo", "Faroe" },
@@ -272,6 +274,7 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "GA", "Gabon" },
             { "ga", "Irlandia" },
             { "GB", "Karajan Manunggal" },
+            { "pcm", "Nigeria Pidgin" },
             { "GD", "Gr\u00e9nada" },
             { "gd", "Gaulia" },
             { "GE", "G\u00e9orgia" },
@@ -284,19 +287,23 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "GM", "Gambia" },
             { "GN", "Guinea" },
             { "GP", "Guad\u00e9lup" },
+            { "GQ", "Guin\u00e9a Katulistiwa" },
             { "und", "Basa Ora Dikenali" },
+            { "GR", "Grikenlan" },
             { "GS", "Georgia Kidul lan Kapuloan Sandwich Kidul" },
             { "GT", "Guat\u00e9mala" },
             { "GU", "Guam" },
             { "gu", "Gujarat" },
             { "gv", "Manx" },
             { "GW", "Guinea-Bissau" },
+            { "rhg", "Rohingya" },
             { "GY", "Guyana" },
             { "ha", "Hausa" },
             { "ckb", "Kurdi Tengah" },
             { "zxx", "Konten tanpa linguistik" },
             { "he", metaValue_he },
             { "hi", "India" },
+            { "de_AT", "J\u00e9rman Ostenrik" },
             { "HK", "Laladan Administratif Astamiwa Hong Kong" },
             { "HM", "Kapuloan Heard lan McDonald" },
             { "HN", "Honduras" },
@@ -320,6 +327,7 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "ii", "Sichuan Yi" },
             { "IL", "Isra\u00e8l" },
             { "IM", "Pulo Man" },
+            { "IN", "Indhia" },
             { "IO", "Wilayah Inggris nang Segoro Hindia" },
             { "IQ", "Irak" },
             { "IR", "Iran" },
@@ -334,6 +342,7 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "Mlym", metaValue_ml },
             { "JE", "Jersey" },
             { "type.ca.islamic", "Tanggalan Islam" },
+            { "doi", "Dogri" },
             { "JM", "Jamaika" },
             { "Beng", "Bangla" },
             { "JO", "Yordania" },
@@ -341,6 +350,8 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "jv", "Jawa" },
             { "guz", "Gusii" },
             { "type.nu.knda", "Digit Kannada" },
+            { "de_CH", "J\u00e9rman Switserlan" },
+            { "mai", "Maithili" },
             { "smn", "Inari Sami" },
             { "ka", metaValue_ka },
             { "type.ca.buddhist", "Tanggalan Buddha" },
@@ -357,10 +368,14 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "KM", "Komoro" },
             { "Knda", metaValue_kn },
             { "kn", metaValue_kn },
+            { "KN", "Saint Kits lan N\u00e8vis" },
+            { "fr_CA", "Prancis Kanada" },
             { "ko", metaValue_ko },
+            { "KP", "Korea Lor" },
             { "KR", "Kor\u00e9a Kidul" },
             { "ks", "Kashmiri" },
             { "ku", "Kurdis" },
+            { "fr_CH", "Prancis Switserlan" },
             { "KW", "Kuwait" },
             { "kw", "Kernowek" },
             { "KY", "Kapuloan K\u00e9man" },
@@ -402,9 +417,11 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "MF", "Santa Martin" },
             { "MG", "Madagaskar" },
             { "mg", "Malagasi" },
+            { "Thai", metaValue_th },
             { "MH", "Kapuloan Marshall" },
             { "type.co.ducet", "Urutan Pamilahan Unicode Default" },
             { "mi", "Maori" },
+            { "MK", "R\u00e9publik Mak\u00e9donia Lor" },
             { "mk", "Makedonia" },
             { "ml", metaValue_ml },
             { "ML", "Mali" },
@@ -446,11 +463,13 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "NL", metaValue_NL },
             { "nn", "Nynorsk Norwegia" },
             { "NO", "Nurw\u00e8gen" },
+            { "no", "Norwegia" },
             { "NP", "N\u00e9pal" },
             { "NR", "Nauru" },
             { "NU", "Niue" },
             { "rof", "Rombo" },
             { "ny", "Nyanja" },
+            { "NZ", "Selandia Anyar" },
             { "kab", "Kabyle" },
             { "kam", "Kamba" },
             { "mer", "Meru" },
@@ -463,6 +482,7 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "PA", "Panama" },
             { "pa", "Punjab" },
             { "dua", "Duala" },
+            { "en_GB", "Inggris Karajan Manunggal" },
             { "PE", "Peru" },
             { "PF", "Polinesia Prancis" },
             { "PG", "Papua Nugini" },
@@ -471,6 +491,7 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "PL", "Polen" },
             { "pl", "Polandia" },
             { "ewo", "Ewondo" },
+            { "PM", "Saint Pi\u00e8r lan Miku\u00e9lon" },
             { "PN", "Kapuloan Pitcairn" },
             { "type.ca.dangi", "Tanggalan Dangi" },
             { "PR", "Pu\u00e8rto Riko" },
@@ -482,6 +503,7 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "PW", "Palau" },
             { "type.nu.greklow", "Angka Huruf Cilik Yunani" },
             { "PY", "Paraguay" },
+            { "pt_BR", "Portugis Brasil" },
             { "Hebr", metaValue_he },
             { "mgh", "Makhuwa-Meeto" },
             { "key.cf", "Format Mata Uang" },
@@ -498,7 +520,8 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "kde", "Makonde" },
             { "001", "Donya" },
             { "Ethi", "Ethiopik" },
-            { "002", "Afrika" },
+            { "002", metaValue_002 },
+            { "003", "Am\u00e9rika Lor" },
             { "RE", "R\u00e9union" },
             { "type.hc.h12", "Sistem 12 Jam (1\u201312)" },
             { "005", "Am\u00e9rika Kidul" },
@@ -509,6 +532,7 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "key.cu", "Mata Uang" },
             { "RO", "Rum\u00e9ni" },
             { "ro", "Rumania" },
+            { "RS", "S\u00e8rbi" },
             { "type.nu.orya", "Digit Odia" },
             { "type.nu.hanidec", "Angka Desimal Mandarin" },
             { "ru", metaValue_RU },
@@ -516,6 +540,7 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "RW", "Rwanda" },
             { "rw", "Kinyarwanda" },
             { "kea", "Kabuverdianu" },
+            { "en_AU", "Inggris Ostrali" },
             { "SA", "Arab Saudi" },
             { "sa", "Sanskerta" },
             { "SB", "Kapuloan Suleman" },
@@ -528,8 +553,10 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "SE", "Sw\u00e8dhen" },
             { "se", "Sami Sisih Lor" },
             { "014", "Afrika W\u00e9tan" },
+            { "015", "Afrika Lor" },
             { "SG", "Singapura" },
             { "sg", "Sango" },
+            { "SH", "Saint H\u00e9l\u00e9na" },
             { "type.lb.strict", "Gaya Ganti Baris Strik" },
             { "si", metaValue_si },
             { "017", "Afrika Sisih Tengah" },
@@ -574,15 +601,16 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "yav", "Yangben" },
             { "143", "Asia Tengah" },
             { "TD", "Chad" },
-            { "te", "Telugu" },
+            { "te", metaValue_te },
             { "145", "Asia Kulon" },
             { "TF", "Wilayah Prancis nang Kutub Kidul" },
             { "TG", "Togo" },
             { "tg", "Tajik" },
+            { "th", metaValue_th },
             { "TH", "Tanah Thai" },
-            { "th", "Thailand" },
             { "ti", "Tigrinya" },
             { "TJ", "Tajikistan" },
+            { "en_CA", "Inggris Kanada" },
             { "029", "Karibia" },
             { "TK", "Tokelau" },
             { "tk", "Turkmen" },
@@ -607,6 +635,7 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "UA", "Ukrania" },
             { "030", "Asia W\u00e9tan" },
             { "151", "\u00c9ropah W\u00e9tan" },
+            { "154", "\u00c9ropah Lor" },
             { "034", "Asia Kidul" },
             { "155", "\u00c9ropah Kulon" },
             { "035", "Asia Kidul-w\u00e9tan" },
@@ -629,6 +658,7 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "tzm", "Tamazight Atlas Tengah" },
             { "nnh", "Ngiemboon" },
             { "VA", "Kutha Vatikan" },
+            { "VC", "Saint Vinsen lan Gr\u00e9nadin" },
             { "VE", "V\u00e9n\u00e9su\u00e9la" },
             { "type.ca.roc", "Tanggalan Minguo" },
             { "VG", "Kapuloan Virgin Britania" },
@@ -653,9 +683,12 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "ar_001", "Arab Standar Anyar" },
             { "WS", metaValue_WS },
             { "Mong", metaValue_MN },
+            { "XA", "Logat Semu" },
+            { "mni", "Manipuri" },
+            { "XB", "Rong Arah Semu" },
             { "Latn", metaValue_la },
             { "061", "Polinesia" },
-            { "type.nu.hans", "Angka Mandarin Prasaja" },
+            { "type.nu.hans", "Angka Mandarin Ringkes" },
             { "type.nu.hant", "Angka Mandarin Tradisional" },
             { "xh", "Xhosa" },
             { "XK", "Kosovo" },
@@ -690,7 +723,8 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "type.nu.jpanfin", "Angka Finansial Jepang" },
             { "ebu", "Embu" },
             { "jmc", "Machame" },
-            { "type.nu.hansfin", "Angka Finansial Mandarin Prasaja" },
+            { "zh_Hans", "Tyonghwa (Ringkes)" },
+            { "type.nu.hansfin", "Angka Finansial Mandarin Ringkes" },
             { "kok", "Konkani" },
             { "type.nu.arabext", "Digit Hindu-Arab Diambakake" },
             { "nus", "Nuer" },
@@ -708,9 +742,11 @@ public class LocaleNames_jv extends OpenListResourceBundle {
             { "sah", "Sakha" },
             { "type.nu.tamldec", "Digit Tamil" },
             { "saq", "Samburu" },
+            { "sat", "Santali" },
             { "key.nu", "Angka" },
             { "Guru", "Gurmukhi" },
             { "ksb", "Shambala" },
+            { "Telu", metaValue_te },
             { "ksf", "Bafia" },
         };
         return data;
