@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -119,7 +115,7 @@ public class LocaleNames_ks extends OpenListResourceBundle {
             { "AT", "\u0622\u0633\u0679\u0650\u06cc\u0627" },
             { "AU", "\u0622\u0633\u0679\u0631\u06cc\u0644\u0650\u06cc\u0627" },
             { "AW", "\u0627\u064e\u0631\u0648\u0657\u0628\u0627" },
-            { "en_US", "\u06cc\u0648\u0657 \u0627\u06cc\u0633 \u0627\u064e\u0646\u06af\u0631\u06cc\u0656\u0632\u06cd" },
+            { "en_US", "\u0627\u0645\u0631\u06cc\u0656\u06a9\u06cc \u0627\u064e\u0646\u065b\u06af\u0631\u06cc\u0656\u0632\u06cd" },
             { "AX", "\u0627\u06cc\u0644\u06cc\u0646\u0691 \u062c\u0654\u0632\u06cc\u0656\u0631\u0655" },
             { "AZ", "\u0622\u0632\u064e\u0631\u0628\u0627\u062c\u0627\u0646" },
             { "%%AREVELA", "\u0645\u064e\u0634\u0631\u0650\u0642\u06cc \u0627\u064e\u0645\u0631\u06cc\u0656\u06a9\u0627" },
@@ -172,6 +168,7 @@ public class LocaleNames_ks extends OpenListResourceBundle {
             { "DE", "\u062c\u0631\u0645\u0654\u0646\u06cc" },
             { "goh", "\u067e\u0631\u0648\u0646 \u06c1\u0627\u06d2 \u062c\u0654\u0631\u0645\u064e\u0646" },
             { "ace", "\u0627\u064e\u0686\u064e\u06d2\u0646\u06cc\u0656\u0632" },
+            { "type.nu.deva", "\u062f\u06cc\u0648\u0646\u0627\u06af\u0631\u06cc \u06c1\u0646\u062f\u0633\u0655\u06c1" },
             { "DJ", "\u062c\u0650\u0628\u0648\u0657\u062a\u06cc" },
             { "DK", "\u0688\u06cc\u0646\u0645\u0627\u0631\u0655\u06a9" },
             { "ach", "\u0627\u064e\u06a9\u0648\u0644\u06cc" },
@@ -220,7 +217,6 @@ public class LocaleNames_ks extends OpenListResourceBundle {
             { "FR", "\u0641\u0631\u0627\u0646\u0633" },
             { "tkl", "\u0679\u0648\u06a9\u06cc\u0656\u0644\u0627\u0648" },
             { "grb", "\u06af\u0631\u0650\u0628\u0648" },
-            { "root", "\u0631\u0648\u0657\u0679" },
             { "grc", "\u0642\u062f\u06cc\u0656\u0645 \u06cc\u0648\u0657\u0646\u0672\u0646\u06cc" },
             { "GA", "\u06af\u06cc\u0628\u0627\u0646" },
             { "vot", "\u0648\u0648\u062a\u0650\u06a9" },
@@ -282,7 +278,7 @@ public class LocaleNames_ks extends OpenListResourceBundle {
             { "ain", "\u0627\u06cc\u0646\u0648\u0657" },
             { "tog", "\u0646\u06cc\u0627\u0633\u0627 \u0679\u0648\u0646\u06af\u0627" },
             { "Kali", "\u06a9\u0627\u06cc\u0627 \u0644\u06cc" },
-            { "de_CH", "\u0633\u0655\u0648\u0650\u0633 \u06c1\u0627\u06d2\u062c\u0654\u0631\u0645\u064e\u0646" },
+            { "de_CH", "\u0633\u0655\u0648\u0650\u0633 \u06c1\u0627\u0626\u06cc \u062c\u0654\u0631\u0645\u064e\u0646" },
             { "type.ca.buddhist", "\u0628\u064f\u062f\u064e\u0646 \u06c1\u064f\u0646\u062f \u06a9\u06cc\u0644\u0646\u0691\u064e\u0631" },
             { "KE", "\u06a9\u0650\u0646\u06cc\u0627" },
             { "419", "\u0644\u0627\u0637\u06cc\u0656\u0646\u06cc \u0627\u064e\u0645\u0631\u06cc\u0656\u06a9\u0627 \u062a\u06c1\u0655 \u06a9\u06cc\u0631\u064e\u0628\u06cc\u0656\u0646" },
@@ -292,11 +288,11 @@ public class LocaleNames_ks extends OpenListResourceBundle {
             { "KM", "\u06a9\u064e\u0645\u0648\u0631\u064e\u0633" },
             { "KN", "\u0633\u06cc\u0646\u0679 \u06a9\u0650\u0679\u064e\u0633 \u062a\u06c1\u0655 \u0646\u06cc\u0648\u0650\u0633" },
             { "Knda", "\u06a9\u064e\u0646\u064e\u0691\u0627" },
-            { "fr_CA", "\u06a9\u064e\u0646\u06cc\u0688\u06cc\u064e\u0646 \u0641\u0631\u06cc\u0646\u0686" },
+            { "fr_CA", "\u06a9\u064e\u0646\u06cc\u0688\u06cc\u064e\u0646 \u0641\u0631\u0627\u0646\u0633\u06cc\u0633\u06cc" },
             { "KP", "\u0634\u064f\u0645\u0672\u0644\u06cc \u06a9\u0648\u0631\u0650\u06cc\u0627" },
             { "KR", "\u062c\u0646\u0648\u0657\u0628\u06cc \u06a9\u0648\u0631\u0650\u06cc\u0627" },
             { "Plrd", "\u067e\u0648\u0644\u0627\u0691 \u067e\u06be\u0648\u0646\u0650\u0679\u0650\u06a9" },
-            { "fr_CH", "\u0633\u0655\u0648\u0655\u0633 \u0641\u0631\u06cc\u0646\u0686" },
+            { "fr_CH", "\u0633\u0655\u0648\u0655\u0633 \u0641\u0631\u0627\u0646\u0633\u06cc\u0633\u06cc" },
             { "KW", "\u06a9\u064f\u0648\u06cc\u062a" },
             { "tpi", "\u0679\u0627\u06a9 \u067e\u0650\u0633\u0650\u0646" },
             { "KY", "\u06a9\u06cc\u0645\u064e\u0646 \u062c\u0654\u0632\u06cc\u0656\u0631\u0655" },
@@ -473,7 +469,7 @@ public class LocaleNames_ks extends OpenListResourceBundle {
             { "ast", "\u0627\u06cc\u0633\u0679\u0648\u0657\u0631\u06cc\u064e\u0646" },
             { "Orkh", "\u0627\u0648\u0631\u06a9\u06be\u0648\u0646" },
             { "TZ", "\u062a\u064e\u0646\u062c\u0627\u0646\u0650\u06cc\u0627" },
-            { "Zzzz", "\u0627\u064e\u0646 \u0632\u0672\u0646\u06cd \u06cc\u0627 \u0646\u0627 \u0644\u064e\u06af\u06c1\u0655 \u06c1\u0627\u0631 \u0631\u064e\u0633\u0645\u064f\u0644 \u062e\u0638" },
+            { "Zzzz", "\u0646\u0627\u0645\u0648\u0644\u0648\u0657\u0645 \u0631\u064e\u0633\u0645 \u0627\u0644\u062e\u0637" },
             { "UA", "\u06cc\u0648\u0657\u0631\u0650\u06a9\u06cc\u0646" },
             { "rup", "\u0627\u064e\u0631\u0648\u0645\u0627\u0646\u06cc" },
             { "030", "\u0645\u064e\u0634\u0631\u0650\u0642\u06cc \u0627\u06cc\u0634\u06cc\u0627" },
@@ -519,6 +515,7 @@ public class LocaleNames_ks extends OpenListResourceBundle {
             { "Blis", "\u0628\u0650\u0644\u0650\u0633 \u0633\u0650\u0645\u0628\u0644\u0632" },
             { "YE", "\u06cc\u064e\u0645\u064e\u0646" },
             { "nqo", metaValue_nqo },
+            { "type.co.standard", "\u0645\u0639\u06cc\u0672\u0631\u06cc \u062a\u0631\u062a\u06cc\u0656\u0628 \u0622\u0688\u0631" },
             { "fan", "\u0641\u06cc\u0646\u06af" },
             { "%%ROZAJ", metaValue_ru },
             { "fat", "\u0641\u0627\u0646\u0679\u06cc" },
@@ -535,6 +532,7 @@ public class LocaleNames_ks extends OpenListResourceBundle {
             { "nso", "\u0634\u0645\u0627\u0644\u06cc \u0633\u062a\u06be\u0648" },
             { "loz", "\u0644\u0648\u0632\u06cc" },
             { "hil", "\u06c1\u0650\u0644\u06cc\u0656\u06af\u06cc\u0646\u064e\u0646" },
+            { "type.nu.arabext", "\u062a\u0648\u0633\u06cc\u0656\u0639 \u0634\u064f\u062f\u06c1 \u0627\u064e\u0631\u0628\u06cc-\u0627\u0650\u0646\u0688\u0650\u06a9 \u06c1\u0646\u062f\u0633\u0655\u06c1" },
             { "dak", "\u0688\u06a9\u0648\u0679\u0627" },
             { "hit", "\u06c1\u0650\u062a\u0627\u06cc\u0650\u062a" },
             { "dar", "\u062f\u064e\u0631\u06af\u0648\u0627" },
@@ -570,12 +568,13 @@ public class LocaleNames_ks extends OpenListResourceBundle {
             { "uga", "\u0627\u064f\u06af\u0627\u0631\u062a\u0650\u06a9" },
             { "bas", "\u0628\u0627\u0633\u0627" },
             { "jrb", "\u062c\u0648\u0688\u06cc\u0648 \u0639\u0631\u0628\u06cc" },
-            { "es_ES", "\u0644\u0650\u0628\u06cc\u0631\u06cc\u064e\u0646 \u0633\u067e\u06cc\u0646\u0650\u0634" },
+            { "es_ES", "\u06cc\u0648\u0657\u0631\u067e\u06cc \u06c1\u0633\u067e\u0627\u0646\u0648\u06cc" },
             { "nzi", "\u0646\u064e\u0638\u06cc\u0656\u0645\u0627" },
             { "sco", "\u0633\u06a9\u0627\u0679\u0633" },
             { "scn", "\u0633\u0650\u0686\u0650\u0644\u0650\u06cc\u064e\u0646" },
             { "aa", "\u0627\u064e\u0641\u0627\u0631" },
             { "ab", "\u0627\u064e\u0628\u062e\u0627\u0632\u0650\u06cc\u0627\u0646" },
+            { "Aran", "\u0646\u0633\u062a\u0639\u0644\u06cc\u0642" },
             { "ae", metaValue_ae },
             { "af", "\u0627\u064e\u0641\u0631\u06cc\u0656\u06a9\u0627\u0646\u0632" },
             { "ak", "\u0627\u064e\u06a9\u0627\u0646" },
@@ -619,7 +618,7 @@ public class LocaleNames_ks extends OpenListResourceBundle {
             { "cy", "\u0648\u06cc\u0644\u0634" },
             { "Yiii", "\u06cc\u0656\u06cc" },
             { "da", "\u0688\u06cc\u0646\u0650\u0634" },
-            { "pt_PT", "\u0644\u0650\u0628\u06cc\u0631\u06cc\u064e\u0646 \u067e\u064f\u0631\u062a\u064e\u06af\u06cc\u0656\u0632" },
+            { "pt_PT", "\u06cc\u0648\u0657\u0631\u067e\u06cc \u067e\u064f\u0631\u062a\u064e\u06af\u06cc\u0656\u0632" },
             { "de", "\u062c\u0654\u0631\u0645\u064e\u0646" },
             { "bej", "\u0628\u06cc\u062c\u0627" },
             { "din", "\u0688\u0650\u0646\u06a9\u0627" },
@@ -627,7 +626,7 @@ public class LocaleNames_ks extends OpenListResourceBundle {
             { "bem", "\u0628\u06cc\u0645\u0628\u0627" },
             { "sga", "\u067e\u0631\u0648\u0646 \u0627\u06cc\u0631\u0650\u0634" },
             { "dv", "\u062f\u0650\u0648\u06cc\u06c1\u06cc" },
-            { "es_419", "\u0644\u06cc\u0679\u0655\u0646 \u0627\u0645\u0631\u06cc\u0656\u06a9\u06cc \u0633\u067e\u06cc\u0646\u0650\u0634" },
+            { "es_419", "\u0644\u0627\u0637\u06cc\u0656\u0646\u06cc \u0627\u0645\u0631\u06cc\u0656\u06a9\u06cc \u06c1\u0633\u067e\u0627\u0646\u0648\u06cc" },
             { "dz", "\u0632\u0648\u0646\u06af\u06a9\u06be\u0627" },
             { "type.ca.chinese", "\u0686\u06cc\u0656\u0646\u06cc \u06a9\u06cc\u0644\u064e\u0646\u0691\u064e\u0631" },
             { "ee", "\u0627\u06cc\u0656\u0648" },
@@ -636,7 +635,7 @@ public class LocaleNames_ks extends OpenListResourceBundle {
             { "en", "\u0627\u064e\u0646\u06af\u06cc\u0656\u0632\u06cd" },
             { "eo", "\u0627\u06cc\u0633\u067e\u064e\u0631\u06cc\u0646\u0679\u0648" },
             { "type.co.big5han", "\u0631\u0620\u0648\u0672\u062a\u06cc \u0686\u06cc\u0656\u0646\u06cc \u062a\u0650\u0631\u062a\u06cc\u0656\u0628" },
-            { "es", "\u0633\u067e\u06cc\u0646\u0650\u0634" },
+            { "es", "\u06c1\u0633\u067e\u0627\u0646\u0648\u06cc" },
             { "et", "\u0627\u06cc\u0633\u0679\u0648\u0646\u06cc\u064e\u0646" },
             { "eu", "\u0628\u0627\u0633\u06a9" },
             { "Buhd", "\u0628\u064f\u06c1\u0650\u062f" },
@@ -647,15 +646,16 @@ public class LocaleNames_ks extends OpenListResourceBundle {
             { "shn", "\u0634\u0627\u0646" },
             { "Hano", "\u06c1\u0627\u0646\u064f\u0646\u0648\u0657" },
             { "fa", "\u0641\u0627\u0631\u0633\u06cc" },
-            { "Hans", "\u0633\u0650\u0645\u067e\u0644\u0650\u0641\u0627\u06cc\u0650\u0691 \u06c1\u0627\u0646" },
-            { "Hant", "\u0679\u0631\u06cc\u0691\u0650\u0634\u064e\u0646\u064e\u0644" },
+            { "Hans", "\u0633\u064e\u06c1\u0644 \ufd3f\u062a\u0631\u062c\u0645\u0639 \u0627\u0650\u0634\u0627\u0631\u0655: \u06cc\u0650\u0645 \u0648\u0631\u0698\u0646 \u0631\u064e\u0633\u0645 \u0627\u0644\u062e\u0637 \u06c1\u064f\u06a9 \u0646\u0627\u0624 \u0686\u06be\u064f \u0686\u06cc\u0656\u0646\u06cc \u0628\u0627\u067e\u062a\u06be \u0632\u064e\u0628\u0627\u0646\u0655 \u0646\u0627\u0624 \u06a9\u0650\u0633 \u0645\u062c\u0645\u0648\u0639\u064e\u0633 \u0633\u0655\u062a\u06cd \u0627\u0650\u0633\u062a\u0639\u0645\u0627\u0644 \u06cc\u0650\u0648\u0627\u0646 \u06a9\u0631\u0646\u0655\u06c1\u06d4\ufd3e" },
+            { "type.nu.latn", "\u0645\u063a\u0631\u0628\u06cc \u06c1\u0646\u062f\u0633\u0655\u06c1" },
+            { "Hant", "\u0631\u0650\u0648\u0672\u062c\u06cc \ufd3f\u062a\u0631\u062c\u0645\u0639 \u0627\u0650\u0634\u0627\u0631\u0655: \u06cc\u0650\u0645 \u0648\u0631\u0698\u0646 \u0631\u064e\u0633\u0645 \u0627\u0644\u062e\u0637 \u06c1\u064f\u06a9 \u0646\u0627\u0624 \u0686\u06be\u064f \u0686\u06cc\u0656\u0646\u06cc \u0628\u0627\u067e\u062a\u06be \u0632\u064e\u0628\u0627\u0646\u0655 \u0646\u0627\u0624 \u06a9\u0650\u0633 \u0645\u062c\u0645\u0648\u0639\u064e\u0633 \u0633\u0655\u062a\u06cd \u0627\u0650\u0633\u062a\u0639\u0645\u0627\u0644 \u06cc\u0650\u0648\u0627\u0646 \u06a9\u0631\u0646\u0655\u06c1\u06d4\ufd3e" },
             { "ff", "\u0641\u064f\u0644\u0627\u06c1" },
             { "fi", "\u0641\u0650\u0646\u0650\u0634" },
             { "fj", "\u0641\u0650\u062c\u06cc\u064e\u0646" },
             { "fon", "\u0641\u0648\u0646" },
             { "fo", "\u0641\u064e\u0631\u0648\u0633" },
             { "umb", "\u06cc\u064f\u0645\u0628\u064f\u0646\u062f\u0648\u0657" },
-            { "fr", "\u0641\u0631\u06cc\u0646\u0686" },
+            { "fr", "\u0641\u0631\u0627\u0646\u0633\u06cc\u0633\u06cc" },
             { "sid", "\u0633\u0650\u062f\u0627\u0645\u0648" },
             { "fy", "\u0645\u063a\u0631\u0628\u06cc \u0641\u0631\u0650\u0634\u06cc\u064e\u0646" },
             { "ga", "\u0627\u064e\u06cc\u0631\u0650\u0634" },
@@ -691,7 +691,7 @@ public class LocaleNames_ks extends OpenListResourceBundle {
             { "frs", "\u0645\u0634\u0631\u0650\u0642\u06cc \u0641\u0631\u0650\u0634\u06cc\u064e\u0646" },
             { "frr", "\u0634\u064f\u0645\u0672\u0644\u06cc \u0641\u0631\u0650\u0634\u06cc\u064e\u0646" },
             { "is", "\u0622\u06cc\u0650\u0633\u0644\u06cc\u0646\u0688\u0650\u06a9" },
-            { "it", "\u0627\u0650\u0679\u06cc\u0644\u06cc\u064e\u0646" },
+            { "it", "\u0627\u0650\u0637\u0627\u0644\u0648\u06cc" },
             { "iu", "\u0627\u0650\u0646\u064f\u06a9\u062a\u0650\u062a\u0648\u0657" },
             { "ja", "\u062c\u0627\u067e\u0672\u0646\u06cd" },
             { "Mlym", "\u0645\u064e\u0644\u06cc\u0627\u0644\u064e\u0645" },
@@ -794,7 +794,7 @@ public class LocaleNames_ks extends OpenListResourceBundle {
             { "ps", "\u067e\u064e\u0634\u062a\u0648\u0657" },
             { "pt", "\u067e\u064f\u0631\u062a\u064e\u06af\u06cc\u0656\u0632" },
             { "mga", "\u0648\u064e\u0633\u062a\u06cc \u0627\u06cc\u0631\u0650\u0634" },
-            { "pt_BR", "\u0628\u0631\u0627\u0632\u06cc\u0656\u0644\u06cc \u067e\u064f\u062a\u064e\u06af\u06cc\u0656\u0632" },
+            { "pt_BR", "\u0628\u0631\u0627\u0632\u06cc\u0656\u0644\u06cc \u067e\u064f\u0631\u062a\u064e\u06af\u06cc\u0656\u0632" },
             { "kcg", "\u062a\u064e\u06cc\u064e\u067e" },
             { "bra", "\u0628\u0631\u062c" },
             { "key.ca", "\u06a9\u06cc\u0644\u0646\u0691\u0631" },
@@ -828,6 +828,7 @@ public class LocaleNames_ks extends OpenListResourceBundle {
             { "sm", "\u0633\u064e\u0645\u0648\u0627\u064e\u0646" },
             { "sn", "\u0634\u0648\u0646\u0627" },
             { "so", "\u0633\u0648\u0645\u0672\u0644\u06cc" },
+            { "type.nu.arab", "\u0627\u064e\u0631\u0628\u06cc-\u0627\u0650\u0646\u0688\u0650\u06a9 \u06c1\u0646\u062f\u0633\u0655\u06c1" },
             { "sq", "\u0627\u0644\u0628\u0627\u0646\u0650\u06cc\u064e\u0646" },
             { "sr", "\u0633\u0654\u0631\u0628\u0650\u06cc\u064e\u0646" },
             { "ss", "\u0633\u0648\u0627\u062a\u06cc" },
@@ -898,7 +899,7 @@ public class LocaleNames_ks extends OpenListResourceBundle {
             { "Latf", "\u0641\u0631\u06a9\u062a\u064f\u0631 \u0644\u06cc\u0679\u0650\u0646" },
             { "gba", "\u06af\u0628\u0627\u06cc\u0627" },
             { "mni", "\u0645\u064e\u0646\u06cc\u067e\u0648\u0657\u0631\u06cc" },
-            { "Latn", "\u0644\u06cc\u0679\u0650\u0646" },
+            { "Latn", "\u0644\u0627\u0637\u06cc\u0656\u0646\u06cc" },
             { "Latg", "\u06af\u06cc\u0644\u0650\u06a9 \u0644\u06cc\u0679\u064e\u0646" },
             { "xh", "\u06a9\u06be\u0648\u0633\u0627" },
             { "byn", "\u0628\u0655\u0644\u0650\u0646" },
@@ -911,13 +912,14 @@ public class LocaleNames_ks extends OpenListResourceBundle {
             { "Syrc", "\u0633\u06cc\u0656\u0631\u0650\u06cc\u064e\u06a9" },
             { "Dsrt", "\u0688\u06cc\u0633\u0654\u0631\u06cc\u0679" },
             { "yo", "\u06cc\u0648\u0631\u064f\u0628\u0627" },
+            { "es_MX", "\u0645\u06cc\u06a9\u0633\u06cc\u06a9\u0646 \u06c1\u0633\u067e\u0627\u0646\u0648\u06cc" },
             { "Syrj", "\u0645\u063a\u0631\u0650\u0628\u06cc \u0633\u06cc\u0656\u0631\u06cc\u064e\u06a9" },
             { "ota", "\u0627\u0648\u0679\u0648\u0645\u064e\u0646 \u062a\u064f\u0631\u06a9\u0650\u0634" },
             { "Syre", "\u0627\u06cc\u0633\u0679\u0631\u06cc\u0646\u062c\u0650\u0644\u0648 \u0633\u06cc\u0656\u0631\u0650\u06cc\u064e\u06a9" },
             { "vai", metaValue_vai },
             { "za", "\u0632\u064f\u06c1\u0627\u0646\u06af" },
             { "Cari", "\u06a9\u0627\u0631\u06cc\u064e\u0646" },
-            { "zh", "\u0686\u06cc\u0656\u0646\u06cc" },
+            { "zh", "\u0686\u06cc\u0656\u0646\u06cc \ufd3f\u062a\u0631\u062c\u0645\u0639 \u0627\u0650\u0634\u0627\u0631\u0655: \u062e\u0627\u0635 \u0637\u0648\u0631\u060c \u0645\u06cc\u0646\u0688\u0627\u0631\u0646 \u0686\u06cc\u0656\u0646\u06cc\u06d4\ufd3e" },
             { "Bopo", "\u0628\u0648\u067e\u0648\u0645\u0648\u0641\u0648" },
             { "Perm", "\u0627\u0648\u0644\u0688 \u067e\u0654\u0631\u0645\u0650\u06a9" },
             { "zu", "\u0632\u064f\u0644\u0648\u0657" },
@@ -933,7 +935,7 @@ public class LocaleNames_ks extends OpenListResourceBundle {
             { "Egyh", "\u0627\u0650\u062c\u0650\u067e\u0634\u064e\u0646 \u06c1\u064e\u06cc\u0631\u06cc\u0679\u0650\u06a9" },
             { "Egyp", "\u0627\u0650\u062c\u0650\u067e\u0634\u064e\u0646 \u06c1\u064e\u06cc\u0631\u0648\u06af\u0644\u0650\u067e\u06be\u0633" },
             { "Geok", "\u062c\u0627\u0631\u062c\u0650\u06cc\u064e\u0646 \u06a9\u06be\u062a\u0633\u0648\u0631\u06cc" },
-            { "zh_Hans", "\u0633\u06cc\u0648\u062f \u0686\u06cc\u0656\u0646\u06cc" },
+            { "zh_Hans", "\u0633\u064e\u06c1\u0644 \u0686\u06cc\u0656\u0646\u06cc" },
             { "Hung", "\u067e\u0631\u0648\u0646 \u06c1\u064e\u0646\u06af\u06cc\u0631\u06cc\u064e\u0646" },
             { "kok", "\u06a9\u0648\u0646\u06a9\u064e\u0646\u06cc" },
             { "%%1901", "\u0631\u0620\u0648\u0672\u062a\u06cc \u062c\u0654\u0631\u0645\u064e\u0646 \u0639\u0650\u0644\u0645\u06c1\u0650 \u06c1\u0650\u062c\u0627" },
