@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -246,7 +246,6 @@ public class LocaleNames_or extends OpenListResourceBundle {
             { "FR", "\u0b2b\u0b4d\u0b30\u0b3e\u0b28\u0b4d\u0b38" },
             { "tkl", metaValue_TK },
             { "grb", "\u0b17\u0b4d\u0b30\u0b47\u0b2c\u0b4b" },
-            { "root", "\u0b30\u0b4b\u0b1f\u0b4d" },
             { "grc", "\u0b2a\u0b4d\u0b30\u0b3e\u0b1a\u0b40\u0b28\u0b4d \u0b5f\u0b41\u0b28\u0b3e\u0b28\u0b40" },
             { "GA", "\u0b17\u0b3e\u0b2c\u0b4b\u0b28\u0b4d" },
             { "vot", "\u0b2d\u0b4b\u0b1f\u0b3f\u0b15\u0b4d" },
@@ -271,6 +270,7 @@ public class LocaleNames_or extends OpenListResourceBundle {
             { "GT", "\u0b17\u0b41\u0b0f\u0b24\u0b2e\u0b3e\u0b32\u0b3e" },
             { "GU", "\u0b17\u0b41\u0b06\u0b2e\u0b4d" },
             { "GW", "\u0b17\u0b41\u0b07\u0b28\u0b3f\u0b06-\u0b2c\u0b3f\u0b38\u0b3e\u0b09" },
+            { "rhg", "\u0b30\u0b4b\u0b39\u0b3f\u0b19\u0b4d\u0b17\u0b4d\u0b5f\u0b3e" },
             { "tli", "\u0b24\u0b4d\u0b32\u0b3f\u0b19\u0b4d\u0b17\u0b3f\u0b1f\u0b4d" },
             { "tlh", "\u0b15\u0b4d\u0b32\u0b3f\u0b19\u0b4d\u0b17\u0b28\u0b4d" },
             { "Talu", "\u0b28\u0b42\u0b24\u0b28 \u0b24\u0b3e\u0b07 \u0b32\u0b41\u0b0f" },
