@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -78,6 +74,14 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] Acre = new String[] {
+               "Acreko ordu estandarra",
+               "",
+               "Acreko udako ordua",
+               "",
+               "Acreko ordua",
+               "",
+            };
         final String[] Apia = new String[] {
                "Apiako ordu estandarra",
                "",
@@ -174,6 +178,14 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] Casey = new String[] {
+               "Caseyko ordua",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Chile = new String[] {
                "Txileko ordu estandarra",
                "",
@@ -278,13 +290,21 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
                "Tongako ordua",
                "",
             };
+        final String[] Yukon = new String[] {
+               "Yukongo ordua",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Alaska = new String[] {
                "Alaskako ordu estandarra",
-               "",
+               "AKST",
                "Alaskako udako ordua",
-               "",
+               "AKDT",
                "Alaskako ordua",
-               "",
+               "AKT",
             };
         final String[] Amazon = new String[] {
                "Amazoniako ordu estandarra",
@@ -519,7 +539,7 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
                "",
             };
         final String[] Norfolk = new String[] {
-               "Norfolk uharteetako ordua estandarra",
+               "Norfolk uharteetako ordu estandarra",
                "",
                "Norfolk uharteetako udako ordua",
                "",
@@ -592,11 +612,11 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             };
         final String[] Atlantic = new String[] {
                "Ipar Amerikako Atlantikoko ordu estandarra",
-               "",
+               "AST",
                "Ipar Amerikako Atlantikoko udako ordua",
-               "",
+               "ADT",
                "Ipar Amerikako Atlantikoko ordua",
-               "",
+               "AT",
             };
         final String[] Brasilia = new String[] {
                "Brasiliako ordu estandarra",
@@ -758,14 +778,6 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
                "Lord Howeko ordua",
                "",
             };
-        final String[] Macquarie = new String[] {
-               "Macquarie uharteko ordua",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Marquesas = new String[] {
                "Markesetako ordua",
                "",
@@ -1048,27 +1060,27 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             };
         final String[] America_Central = new String[] {
                "Ipar Amerikako erdialdeko ordu estandarra",
-               "",
+               "CST",
                "Ipar Amerikako erdialdeko udako ordua",
-               "",
+               "CDT",
                "Ipar Amerikako erdialdeko ordua",
-               "",
+               "CT",
             };
         final String[] America_Eastern = new String[] {
                "Ipar Amerikako ekialdeko ordu estandarra",
-               "",
+               "EST",
                "Ipar Amerikako ekialdeko udako ordua",
-               "",
+               "EDT",
                "Ipar Amerikako ekialdeko ordua",
-               "",
+               "ET",
             };
         final String[] America_Pacific = new String[] {
                "Ipar Amerikako Pazifikoko ordu estandarra",
-               "",
+               "PST",
                "Ipar Amerikako Pazifikoko udako ordua",
-               "",
+               "PDT",
                "Ipar Amerikako Pazifikoko ordua",
-               "",
+               "PT",
             };
         final String[] French_Southern = new String[] {
                "Frantziaren lurralde austral eta antartikoetako ordutegia",
@@ -1088,11 +1100,11 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             };
         final String[] Hawaii_Aleutian = new String[] {
                "Hawaii-Aleutiar uharteetako ordu estandarra",
-               "",
+               "HAST",
                "Hawaii-Aleutiar uharteetako udako ordua",
-               "",
+               "HADT",
                "Hawaii-Aleutiar uharteetako ordua",
-               "",
+               "HAT",
             };
         final String[] Phoenix_Islands = new String[] {
                "Phoenix uharteetako ordua",
@@ -1112,11 +1124,11 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             };
         final String[] America_Mountain = new String[] {
                "Ipar Amerikako mendialdeko ordu estandarra",
-               "",
+               "MST",
                "Ipar Amerikako mendialdeko udako ordua",
-               "",
+               "MDT",
                "Ipar Amerikako mendialdeko ordua",
-               "",
+               "MT",
             };
         final String[] Marshall_Islands = new String[] {
                "Marshall Uharteetako ordua",
@@ -1237,7 +1249,16 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "America/Chicago", America_Central },
             { "America/New_York", America_Eastern },
             { "America/Indianapolis", America_Eastern },
-            { "Pacific/Honolulu", Hawaii_Aleutian },
+            { "Pacific/Honolulu",
+                new String[] {
+                    "Hawaii-Aleutiar uharteetako ordu estandarra",
+                    "HST",
+                    "Hawaii-Aleutiar uharteetako udako ordua",
+                    "HDT",
+                    "Hawaii-Aleutiar uharteetako ordua",
+                    "HST",
+                }
+            },
             { "America/Anchorage", Alaska },
             { "America/Halifax", Atlantic },
             { "America/Sitka", Alaska },
@@ -1292,7 +1313,7 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
             { "Asia/Almaty", Kazakhstan_Eastern },
             { "Asia/Anadyr", Anadyr },
@@ -1429,7 +1450,16 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "Pacific/Efate", Vanuatu },
             { "Pacific/Nauru", Nauru },
             { "Pacific/Palau", Palau },
-            { "SystemV/HST10", Hawaii_Aleutian },
+            { "SystemV/HST10",
+                new String[] {
+                    "Hawaii-Aleutiar uharteetako ordu estandarra",
+                    "HST",
+                    "Hawaii-Aleutiar uharteetako udako ordua",
+                    "HDT",
+                    "Hawaii-Aleutiar uharteetako ordua",
+                    "HST",
+                }
+            },
             { "Africa/Abidjan", GMT },
             { "Africa/Algiers", Europe_Central },
             { "Africa/Conakry", GMT },
@@ -1442,7 +1472,7 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Pacific },
+            { "America/Dawson", Yukon },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1518,7 +1548,7 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "America/Moncton", Atlantic },
             { "America/Nipigon", America_Eastern },
             { "America/Noronha", Noronha },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Ojinaga", America_Central },
             { "America/Tijuana", America_Pacific },
             { "America/Toronto", America_Eastern },
             { "America/Tortola", Atlantic },
@@ -1557,6 +1587,7 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "America/Barbados", Atlantic },
             { "America/Dominica", Atlantic },
             { "America/Edmonton", America_Mountain },
+            { "America/Eirunepe", Acre },
             { "America/Mazatlan", Mexico_Pacific },
             { "America/Miquelon", Pierre_Miquelon },
             { "America/Montreal", America_Eastern },
@@ -1567,7 +1598,7 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
-            { "Antarctica/Casey", Australia_Western },
+            { "Antarctica/Casey", Casey },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
@@ -1603,7 +1634,7 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "America/Araguaina", Brasilia },
             { "America/Boa_Vista", Amazon },
             { "America/Catamarca", Argentina },
-            { "America/Chihuahua", Mexico_Pacific },
+            { "America/Chihuahua", America_Central },
             { "America/Fortaleza", Brasilia },
             { "America/Glace_Bay", Atlantic },
             { "America/Goose_Bay", Atlantic },
@@ -1646,8 +1677,9 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "America/Montevideo", Uruguay },
             { "America/Montserrat", Atlantic },
             { "America/Paramaribo", Suriname },
+            { "America/Rio_Branco", Acre },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Pacific },
+            { "America/Whitehorse", Yukon },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1687,7 +1719,7 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "America/Rankin_Inlet", America_Central },
             { "America/Santa_Isabel", Mexico_Northwest },
             { "America/Scoresbysund", Greenland_Eastern },
-            { "Antarctica/Macquarie", Macquarie },
+            { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
@@ -1727,6 +1759,7 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Dhaka", "Dhaka" },
             { "timezone.excity.Asia/Dubai", "Dubai" },
             { "timezone.excity.Asia/Kabul", "Kabul" },
+            { "timezone.excity.Asia/Macau", "Macau" },
             { "timezone.excity.Asia/Qatar", "Qatar" },
             { "timezone.excity.Asia/Seoul", "Seul" },
             { "timezone.excity.Asia/Tokyo", "Tokio" },
