@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -1530,7 +1530,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "America/Moncton", Atlantic },
             { "America/Nipigon", America_Eastern },
             { "America/Noronha", Noronha },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Ojinaga", America_Central },
             { "America/Tijuana", America_Pacific },
             { "America/Toronto", America_Eastern },
             { "America/Tortola", Atlantic },
@@ -1616,7 +1616,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "America/Araguaina", Brasilia },
             { "America/Boa_Vista", Amazon },
             { "America/Catamarca", Argentina },
-            { "America/Chihuahua", Mexico_Pacific },
+            { "America/Chihuahua", America_Central },
             { "America/Fortaleza", Brasilia },
             { "America/Glace_Bay", Atlantic },
             { "America/Goose_Bay", Atlantic },
