@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -182,6 +178,14 @@ public class TimeZoneNames_hr extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] Casey = new String[] {
+               "vrijeme Caseyja",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Chile = new String[] {
                "\u010dileansko standardno vrijeme",
                "",
@@ -286,6 +290,14 @@ public class TimeZoneNames_hr extends TimeZoneNamesBundle {
                "vrijeme Tonge",
                "",
             };
+        final String[] Yukon = new String[] {
+               "jukon\u0161ko vrijeme",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Alaska = new String[] {
                "alja\u0161ko standardno vrijeme",
                "",
@@ -383,7 +395,7 @@ public class TimeZoneNames_hr extends TimeZoneNamesBundle {
                "",
             };
         final String[] Ponape = new String[] {
-               "vrijeme Ponapea",
+               "ponapejsko vrijeme",
                "",
                "",
                "",
@@ -679,7 +691,7 @@ public class TimeZoneNames_hr extends TimeZoneNamesBundle {
                "",
             };
         final String[] Pitcairn = new String[] {
-               "vrijeme Pitcairna",
+               "pitcairnsko vrijeme",
                "",
                "",
                "",
@@ -766,14 +778,6 @@ public class TimeZoneNames_hr extends TimeZoneNamesBundle {
                "vrijeme otoka Lord Howe",
                "",
             };
-        final String[] Macquarie = new String[] {
-               "vrijeme otoka Macquarie",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Marquesas = new String[] {
                "marki\u017eansko vrijeme",
                "",
@@ -1300,7 +1304,7 @@ public class TimeZoneNames_hr extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
             { "Asia/Almaty", Kazakhstan_Eastern },
             { "Asia/Anadyr", Anadyr },
@@ -1450,7 +1454,7 @@ public class TimeZoneNames_hr extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Pacific },
+            { "America/Dawson", Yukon },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1526,7 +1530,7 @@ public class TimeZoneNames_hr extends TimeZoneNamesBundle {
             { "America/Moncton", Atlantic },
             { "America/Nipigon", America_Eastern },
             { "America/Noronha", Noronha },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Ojinaga", America_Central },
             { "America/Tijuana", America_Pacific },
             { "America/Toronto", America_Eastern },
             { "America/Tortola", Atlantic },
@@ -1576,7 +1580,7 @@ public class TimeZoneNames_hr extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
-            { "Antarctica/Casey", Australia_Western },
+            { "Antarctica/Casey", Casey },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
@@ -1612,7 +1616,7 @@ public class TimeZoneNames_hr extends TimeZoneNamesBundle {
             { "America/Araguaina", Brasilia },
             { "America/Boa_Vista", Amazon },
             { "America/Catamarca", Argentina },
-            { "America/Chihuahua", Mexico_Pacific },
+            { "America/Chihuahua", America_Central },
             { "America/Fortaleza", Brasilia },
             { "America/Glace_Bay", Atlantic },
             { "America/Goose_Bay", Atlantic },
@@ -1657,7 +1661,7 @@ public class TimeZoneNames_hr extends TimeZoneNamesBundle {
             { "America/Paramaribo", Suriname },
             { "America/Rio_Branco", Acre },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Pacific },
+            { "America/Whitehorse", Yukon },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1697,7 +1701,7 @@ public class TimeZoneNames_hr extends TimeZoneNamesBundle {
             { "America/Rankin_Inlet", America_Central },
             { "America/Santa_Isabel", Mexico_Northwest },
             { "America/Scoresbysund", Greenland_Eastern },
-            { "Antarctica/Macquarie", Macquarie },
+            { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
@@ -1800,7 +1804,7 @@ public class TimeZoneNames_hr extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Paris", "Pariz" },
             { "timezone.excity.Europe/Sofia", "Sofija" },
             { "timezone.excity.Europe/Vaduz", "Vaduz" },
-            { "timezone.excity.Indian/Cocos", "Kokosovi otoci" },
+            { "timezone.excity.Indian/Cocos", "Cocos" },
             { "timezone.excity.Pacific/Apia", "Apia" },
             { "timezone.excity.Pacific/Fiji", "Fid\u017ei" },
             { "timezone.excity.Pacific/Guam", "Guam" },
@@ -1855,7 +1859,7 @@ public class TimeZoneNames_hr extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Zagreb", "Zagreb" },
             { "timezone.excity.Europe/Zurich", "Z\u00fcrich" },
             { "timezone.excity.Indian/Chagos", "Chagos" },
-            { "timezone.excity.Indian/Comoro", "Komori" },
+            { "timezone.excity.Indian/Comoro", "Comoro" },
             { "timezone.excity.Pacific/Efate", "Efate" },
             { "timezone.excity.Pacific/Nauru", "Nauru" },
             { "timezone.excity.Pacific/Palau", "Palau" },
@@ -1904,7 +1908,7 @@ public class TimeZoneNames_hr extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Vilnius", "Vilnius" },
             { "timezone.excity.Indian/Mayotte", "Mayotte" },
             { "timezone.excity.Indian/Reunion", "R\u00e9union" },
-            { "timezone.excity.Pacific/Easter", "Uskr\u0161nji otok" },
+            { "timezone.excity.Pacific/Easter", "Easter" },
             { "timezone.excity.Pacific/Kosrae", "Kosrae" },
             { "timezone.excity.Pacific/Majuro", "Majuro" },
             { "timezone.excity.Pacific/Midway", "Midway" },
@@ -2010,7 +2014,7 @@ public class TimeZoneNames_hr extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Stockholm", "Stockholm" },
             { "timezone.excity.Europe/Ulyanovsk", "Uljanovsk" },
             { "timezone.excity.Europe/Volgograd", "Volgograd" },
-            { "timezone.excity.Indian/Christmas", "Bo\u017ei\u0107ni otok" },
+            { "timezone.excity.Indian/Christmas", "Christmas" },
             { "timezone.excity.Indian/Kerguelen", "Kerguelen" },
             { "timezone.excity.Indian/Mauritius", "Mauricijus" },
             { "timezone.excity.Pacific/Auckland", "Auckland" },
@@ -2096,7 +2100,7 @@ public class TimeZoneNames_hr extends TimeZoneNamesBundle {
             { "timezone.excity.America/Thunder_Bay", "Thunder Bay" },
             { "timezone.excity.America/Yellowknife", "Yellowknife" },
             { "timezone.excity.Arctic/Longyearbyen", "Longyearbyen" },
-            { "timezone.excity.Atlantic/Cape_Verde", "Zelenortski Otoci" },
+            { "timezone.excity.Atlantic/Cape_Verde", "Cape Verde" },
             { "timezone.excity.Australia/Lord_Howe", "Lord Howe" },
             { "timezone.excity.Australia/Melbourne", "Melbourne" },
             { "timezone.excity.Indian/Antananarivo", "Antananarivo" },
